@@ -9,16 +9,8 @@ including batch and real-time processing capabilities.
 
 import logging
 import os
-from dotenv import load_dotenv
 from contextvars import ContextVar
 
-# .env 파일 로드 (config 파일에서 환경변수 읽기)
-load_dotenv(dotenv_path="config")
-
-# 로깅 환경변수 설정 (공통 관리)
-LOG_LEVEL = os.getenv("LOG_LEVEL", "INFO")
-LOG_FILE = os.getenv("LOG_FILE", "logsentinelai.log")
-
 # Add context for @log_type so every log line can include it in the header
 LOG_TYPE_CTX: ContextVar[str] = ContextVar("log_type", default="unknown")
 
@@ -29,16 +21,20 @@ def set_log_type(log_type: str):
     except Exception:
         LOG_TYPE_CTX.set("unknown")
 
-def setup_logger(name="logsentinelai", level=LOG_LEVEL):
+def setup_logger(name="logsentinelai", level=None):
     """
     Set up and return a logger with the specified name and level.
     """
+    # Read environment variables at runtime to ensure config file has been loaded
+    log_level = level or os.getenv("LOG_LEVEL", "INFO")
+    log_file = os.getenv("LOG_FILE", "logsentinelai.log")
+    
     logger = logging.getLogger(name)
     if not logger.hasHandlers():
         # Include @log_type right after LOG_LEVEL in the header
         formatter = logging.Formatter('[%(asctime)s] [%(levelname)s] [%(log_type)s] (%(name)s) %(message)s')
-        if LOG_FILE:
-            file_handler = logging.FileHandler(LOG_FILE)
+        if log_file:
+            file_handler = logging.FileHandler(log_file)
             file_handler.setFormatter(formatter)
             logger.addHandler(file_handler)
         # Inject @log_type into each record
@@ -50,24 +46,22 @@ def setup_logger(name="logsentinelai", level=LOG_LEVEL):
                     record.log_type = "unknown"
                 return True
         logger.addFilter(LogTypeFilter())
-    logger.setLevel(getattr(logging, str(level).upper(), logging.INFO))
+    logger.setLevel(getattr(logging, str(log_level).upper(), logging.INFO))
     return logger
 
 # 공통 logger 객체 생성
-logger = setup_logger("logsentinelai.core.commons", LOG_LEVEL)
+logger = setup_logger("logsentinelai.core.commons")
 import json
 from rich import print_json
 import datetime
 from typing import Dict, Any, Optional, List
 
 # Import from modularized components
-from .config import (
-    get_analysis_config, LLM_PROVIDER, LLM_MODELS
-)
+from . import config as config_module
 from .llm import initialize_llm_model, generate_with_model, wait_on_failure
 from .elasticsearch import send_to_elasticsearch_raw
 from .geoip import enrich_source_ips_with_geoip
-from .utils import chunked_iterable, print_chunk_contents
+from ..utils.general import chunked_iterable, print_chunk_contents
 from .monitoring import RealtimeLogMonitor, create_realtime_monitor
 from .token_utils import count_tokens
 
@@ -344,13 +338,13 @@ def run_generic_batch_analysis(log_type: str, analysis_schema_class, prompt_temp
     print("=" * 70)
     
     # Get LLM configuration
-    llm_provider = LLM_PROVIDER
-    llm_model_name = LLM_MODELS.get(LLM_PROVIDER, "unknown")
+    llm_provider = config_module.LLM_PROVIDER
+    llm_model_name = config_module.LLM_MODELS.get(config_module.LLM_PROVIDER, "unknown")
     logger.info(f"Using LLM provider: {llm_provider}, model: {llm_model_name}")
     
     # Get analysis configuration
     try:
-        config = get_analysis_config(
+        config = config_module.get_analysis_config(
             log_type,
             chunk_size=chunk_size,
             analysis_mode="batch",
@@ -508,13 +502,13 @@ def run_generic_realtime_analysis(log_type: str, analysis_schema_class, prompt_t
         logger.info(f"Sampling threshold set to: {sampling_threshold}")
     
     # Get LLM configuration  
-    llm_provider = LLM_PROVIDER
-    llm_model_name = LLM_MODELS.get(LLM_PROVIDER, "unknown")
+    llm_provider = config_module.LLM_PROVIDER
+    llm_model_name = config_module.LLM_MODELS.get(config_module.LLM_PROVIDER, "unknown")
     logger.info(f"Using LLM provider: {llm_provider}, model: {llm_model_name}")
     
     # Get configuration
     try:
-        config = get_analysis_config(
+        config = config_module.get_analysis_config(
             log_type, 
             chunk_size, 
             analysis_mode="realtime",
