@@ -49,6 +49,7 @@ ELASTICSEARCH_INDEX: str = "logsentinelai-analysis"
 TELEGRAM_ENABLED: bool = True
 TELEGRAM_TOKEN: str = ""
 TELEGRAM_CHAT_ID: str = ""
+TELEGRAM_ALERT_LEVEL: str = "CRITICAL"
 
 
 def _load_values() -> None:
@@ -56,7 +57,7 @@ def _load_values() -> None:
     global LLM_PROVIDER, LLM_MODELS, LLM_API_HOSTS, LLM_TEMPERATURE, LLM_TOP_P, LLM_MAX_TOKENS
     global RESPONSE_LANGUAGE, ANALYSIS_MODE, LOG_PATHS, REALTIME_CONFIG, DEFAULT_REMOTE_SSH_CONFIG
     global LOG_CHUNK_SIZES, GEOIP_CONFIG, ELASTICSEARCH_HOST, ELASTICSEARCH_USER
-    global ELASTICSEARCH_PASSWORD, ELASTICSEARCH_INDEX, TELEGRAM_ENABLED, TELEGRAM_TOKEN, TELEGRAM_CHAT_ID
+    global ELASTICSEARCH_PASSWORD, ELASTICSEARCH_INDEX, TELEGRAM_ENABLED, TELEGRAM_TOKEN, TELEGRAM_CHAT_ID, TELEGRAM_ALERT_LEVEL
     LLM_PROVIDER = os.getenv("LLM_PROVIDER", "openai")
     LLM_MODELS = {
         "ollama": os.getenv("LLM_MODEL_OLLAMA", "qwen2.5-coder:3b"),
@@ -125,6 +126,7 @@ def _load_values() -> None:
     TELEGRAM_ENABLED = os.getenv("TELEGRAM_ENABLED", "true").lower() == "true"
     TELEGRAM_TOKEN = os.getenv("TELEGRAM_TOKEN", "")
     TELEGRAM_CHAT_ID = os.getenv("TELEGRAM_CHAT_ID", "")
+    TELEGRAM_ALERT_LEVEL = os.getenv("TELEGRAM_ALERT_LEVEL", "CRITICAL").upper()
 
     logger.info(f"Configuration loaded (config_file={CONFIG_FILE_PATH})")
 
