@@ -172,3 +172,87 @@ def get_httpd_server_error_prompt():
 def get_linux_system_prompt():
     """Get Linux system log analysis prompt"""
     return PROMPT_TEMPLATE_LINUX_SYSTEM_LOG
+
+PROMPT_TEMPLATE_GENERAL_LOG = """
+Expert general log security analyst. Analyze any type of log data for security events, errors, and notable patterns.
+
+LOG ANALYSIS APPROACH:
+- FIRST: Automatically detect log format(s) - Apache/Nginx access, JSON API logs, syslog, database logs, application logs, custom formats, etc.
+- SECOND: Parse and extract key information based on detected format(s)
+- THIRD: Analyze for security events, errors, performance issues, and business logic events
+- FOURTH: Provide comprehensive pattern analysis and monitoring recommendations
+
+FORMAT DETECTION:
+- Common Web Logs: Apache/Nginx access logs, error logs (Combined, Common, custom formats)
+- Structured Logs: JSON, XML, CSV, key-value pairs
+- System Logs: Syslog, systemd journal, Windows Event Log format
+- Application Logs: Database logs, Java/Python/Node.js application logs
+- Security Logs: Firewall, IDS/IPS, authentication systems
+- Custom Formats: Any structured or semi-structured log format
+
+SEVERITY ASSESSMENT:
+- CRITICAL: Active security breaches, system failures, data corruption, unauthorized access
+- HIGH: Clear attack patterns, significant errors, performance degradation, security violations
+- MEDIUM: Suspicious activities, warnings that need investigation, configuration issues
+- LOW: Minor anomalies, performance notices, routine warnings
+- INFO: Normal operations with monitoring value, business transactions, successful operations
+
+EVENT CATEGORIZATION:
+- SECURITY: Authentication failures, authorization issues, attack patterns, intrusion attempts
+- ERROR: System errors, application crashes, failed operations, exceptions
+- WARNING: Configuration issues, performance warnings, deprecated features
+- PERFORMANCE: Slow queries, high response times, resource exhaustion
+- ACCESS: User access patterns, API usage, file access
+- AUTHENTICATION: Login attempts, session management, password changes
+- AUTHORIZATION: Permission checks, role assignments, access denials
+- NETWORK: Connection issues, network errors, DNS problems
+- DATABASE: Query errors, connection problems, transaction issues
+- APPLICATION: Business logic events, workflow steps, feature usage
+- SYSTEM: Service starts/stops, configuration changes, maintenance
+- USER_ACTION: User interactions, data modifications, feature usage
+- BUSINESS_LOGIC: Business process events, transaction flows
+
+MANDATORY EVENT CREATION RULES:
+- NEVER LEAVE events ARRAY EMPTY - This is strictly forbidden
+- ALWAYS create at least 1 event per chunk, even for completely normal logs
+- For normal operations: Create INFO level events documenting patterns and entities
+- For INFO events: Document log patterns, source analysis, and monitoring insights
+
+PATTERN ANALYSIS REQUIREMENTS:
+- Identify all log formats present in the chunk
+- Extract timestamp patterns and normalize them
+- Identify common fields across different log entries
+- Determine log sources/applications generating the logs
+- Analyze traffic patterns, error rates, and trends
+
+KEY REQUIREMENTS:
+- Include complete source IP analysis for security monitoring
+- Provide detailed descriptions explaining the significance of each event
+- Recommend specific actions with commands/procedures where applicable
+- Set confidence scores as decimals (0.0-1.0, not percentages)
+- Document log pattern analysis for better monitoring setup
+- For normal traffic: Create comprehensive INFO events with entity analysis
+
+STATISTICS REQUIREMENTS:
+- Fill the statistics_event object with accurate category counts:
+  * total_events: Total number of events detected
+  * Category counts: security_events, error_events, warning_events, performance_events, access_events, authentication_events, authorization_events, network_events, database_events, application_events, system_events, user_action_events, business_logic_events, unknown_events
+- Fill the statistics_severity object with accurate severity counts:
+  * Severity counts: critical_events, high_events, medium_events, low_events, info_events
+- Fill analysis metadata fields separately:
+  * unique_sources: Number of unique log sources/applications detected
+  * requires_human_review_count: Number of events requiring human review
+- Ensure all statistics objects and metadata fields accurately reflect your event analysis for monitoring insights
+
+LANGUAGE: {response_language}
+
+JSON schema: {model_schema}
+
+<LOGS BEGIN>
+{logs}
+<LOGS END>
+"""
+
+def get_general_log_prompt():
+    """Get general log analysis prompt"""
+    return PROMPT_TEMPLATE_GENERAL_LOG
